package com.zyc.system.service;

import java.util.List;
import com.zyc.system.domain.Microservices;

/**
 * 微服务Service接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface IMicroservicesService 
{
    /**
     * 查询微服务
     * 
     * @param id 微服务主键
     * @return 微服务
     */
    public Microservices selectMicroservicesById(Integer id);

    /**
     * 查询微服务列表
     * 
     * @param microservices 微服务
     * @return 微服务集合
     */
    public List<Microservices> selectMicroservicesList(Microservices microservices);

    /**
     * 新增微服务
     * 
     * @param microservices 微服务
     * @return 结果
     */
    public int insertMicroservices(Microservices microservices);

    /**
     * 修改微服务
     * 
     * @param microservices 微服务
     * @return 结果
     */
    public int updateMicroservices(Microservices microservices);

    /**
     * 批量删除微服务
     * 
     * @param ids 需要删除的微服务主键集合
     * @return 结果
     */
    public int deleteMicroservicesByIds(Integer[] ids);

    /**
     * 删除微服务信息
     * 
     * @param id 微服务主键
     * @return 结果
     */
    public int deleteMicroservicesById(Integer id);
}
